---
lang: en
---

## OSS

### denoland/rusty_v8

rusty_v8 is the wrapper of V8 API in rust.

- This week ICU support of V8 API has been landed. This will enables `Intl` namespace in deno.

  <blockquote class="twitter-tweet"><p lang="en" dir="ltr">ICU support has been landed to rusty_v8 <a href="https://t.co/h3YdnGlpgX">https://t.co/h3YdnGlpgX</a></p>&mdash; Yoshiya Hinosawa (@kt3k) <a href="https://twitter.com/kt3k/status/1359360089405095941?ref_src=twsrc%5Etfw">February 10, 2021</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>

### denoland/deno_std

- This week I tried to run tailwind CLI and found many issues in deno's node.js compatibility library.

  One of the issues was the lack of `Object.prototype.__proto__` in Deno. That object is intentionally deleted in Deno for the security reason. This is nothing wrong, but in Node.js, `Object.prototype.__proto__` is available and actually some npm modules depend on it. So we need to provide `Object.prototype.__proto__` to support some of the npm modules. After some research I found a library called [proto-polyfill](https://github.com/webcarrot/proto-polyfill). This is polyfill of `__proto__` for IE9 or IE10, but I found that it also works for Deno.

  So the code like the below provides `__proto__` to npm modules, and it works better in terms of compatibility.

  ```
  import { createRequire } from "https://deno.land/std/node/module.ts";
  await import("https://raw.githubusercontent.com/webcarrot/proto-polyfill/master/index.js");
  const require = createRequire(import.meta.url);
  const chalk = require('chalk');
  ```

  I found it's very interesting that a library for very old browsers happened to work for the new JavaScript runtime like Deno. This is something the author of the above library probably never imagined when creating it.

### mdubourg001/ssgo

SSGO is a static site generator for Deno

- I started using SSGO. It's very flexible, generic generator. Probably fits most needs in various situations.

## Tech

### Temporal

- Temporal API is freezed, which means the editors of this proposal will never change it unless some unexpected problem happen.

## Life

### Iyo's kitchen

- This week's Iyo's kitchen!

  <blockquote class="twitter-tweet"><p lang="ja" dir="ltr"><a href="https://twitter.com/hashtag/kt3kmeal?src=hash&amp;ref_src=twsrc%5Etfw">#kt3kmeal</a> パスタ、サラダ <a href="https://t.co/mRICl7JTMh">pic.twitter.com/mRICl7JTMh</a></p>&mdash; Yoshiya Hinosawa (@kt3k) <a href="https://twitter.com/kt3k/status/1359111399805308931?ref_src=twsrc%5Etfw">February 9, 2021</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>

### Iseya

- Iyo-chan and I went to Dote no Iseya, Taito ward, Tokyo. It's a Tempura restaurant which has been running for over 100 years! We ordered Tendon (Tempura on rice in big bowl). It was so delicious. The interior of the building was also awesome. It is made of wood, but it escaped the fire of WWII. So it's a very rare wooden building which continue existing before the war in Tokyo.

  <blockquote class="twitter-tweet"><p lang="ja" dir="ltr"><a href="https://twitter.com/hashtag/kt3kmeal?src=hash&amp;ref_src=twsrc%5Etfw">#kt3kmeal</a> 土手の伊勢屋、「ハ」天丼 <a href="https://t.co/hVMWZBxgGY">pic.twitter.com/hVMWZBxgGY</a></p>&mdash; Yoshiya Hinosawa (@kt3k) <a href="https://twitter.com/kt3k/status/1360794509987115008?ref_src=twsrc%5Etfw">February 14, 2021</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>

### Valentine's day

- I got the velentaine's day present from Iyo-chan 🥰

  <blockquote class="twitter-tweet"><p lang="ja" dir="ltr"><a href="https://twitter.com/hashtag/kt3kmeal?src=hash&amp;ref_src=twsrc%5Etfw">#kt3kmeal</a> 手作りカヌレ追加 <a href="https://t.co/bwhh3io05G">pic.twitter.com/bwhh3io05G</a></p>&mdash; Yoshiya Hinosawa (@kt3k) <a href="https://twitter.com/kt3k/status/1360938783198224413?ref_src=twsrc%5Etfw">February 14, 2021</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>
